[cig-commits] r20422 - in cs/spatialdata/trunk: libsrc/geocoords spatialdata/geocoords

brad at geodynamics.org brad at geodynamics.org
Wed Jun 27 14:35:50 PDT 2012


Author: brad
Date: 2012-06-27 14:35:50 -0700 (Wed, 27 Jun 2012)
New Revision: 20422

Modified:
   cs/spatialdata/trunk/libsrc/geocoords/CSGeoProj.hh
   cs/spatialdata/trunk/spatialdata/geocoords/CSGeoProj.py
Log:
Added more comments.

Modified: cs/spatialdata/trunk/libsrc/geocoords/CSGeoProj.hh
===================================================================
--- cs/spatialdata/trunk/libsrc/geocoords/CSGeoProj.hh	2012-06-27 21:10:44 UTC (rev 20421)
+++ cs/spatialdata/trunk/libsrc/geocoords/CSGeoProj.hh	2012-06-27 21:35:50 UTC (rev 20422)
@@ -57,16 +57,16 @@
 
   /** Set origin of local projected coordinate system.
    *
-   * @param lon Longitude of origin (degrees)
-   * @param lat Latitude of origin (degrees)
+   * @param lon Longitude of origin (degrees, WGS84)
+   * @param lat Latitude of origin (degrees, WGS84)
    */
   void origin(const double lon,
 	      const double lat);
 
   /** Get origin of local projected coordinate system.
    *
-   * @param pLon Pointer to longitude of origin (degrees)
-   * @param pLat Pointer to latitude of origin (degrees)
+   * @param pLon Pointer to longitude of origin (degrees, WGS84)
+   * @param pLat Pointer to latitude of origin (degrees, WGS84)
    */
   void origin(double* pLon,
 	      double* pLat);  

Modified: cs/spatialdata/trunk/spatialdata/geocoords/CSGeoProj.py
===================================================================
--- cs/spatialdata/trunk/spatialdata/geocoords/CSGeoProj.py	2012-06-27 21:10:44 UTC (rev 20421)
+++ cs/spatialdata/trunk/spatialdata/geocoords/CSGeoProj.py	2012-06-27 21:35:50 UTC (rev 20422)
@@ -42,8 +42,8 @@
     ## Python object for managing CSGeoProj facilities and properties.
     ##
     ## \b Properties
     ## @li origin_lon Longitude of local origin in degrees.
     ## @li origin_lat Latitude of local origin in degrees.
     ## @li rotation_angle Rotation angle (CCW) of local x-axis from east.
     ##
     ## \b Facilities
@@ -52,10 +52,10 @@
     import pyre.inventory
 
     originLon = pyre.inventory.float("origin_lon", default=0.0)
-    originLon.meta['tip'] = "Longitude of local origin in degrees."
+    originLon.meta['tip'] = "Longitude of local origin in degrees (WGS84)."
 
     originLat = pyre.inventory.float("origin_lat", default=0.0)
-    originLat.meta['tip'] = "Latitude of local origin in degrees."
+    originLat.meta['tip'] = "Latitude of local origin in degrees (WGS84)."
 
     rotAngle = pyre.inventory.float("rotation_angle", default=0.0)
     rotAngle.meta['tip'] = "Rotation angle (CCW) of local x-axis from east."
@@ -42,8 +42,8 @@
     ##
     ## \b Properties
-    ## @li origin_lon Longitude of local origin in degrees.
-    ## @li origin_lat Latitude of local origin in degrees.
+    ## @li origin_lon Longitude of local origin in degrees (WGS84).
+    ## @li origin_lat Latitude of local origin in degrees (WGS84).
     ## @li rotation_angle Rotation angle (CCW) of local x-axis from east.
     ##



More information about the CIG-COMMITS mailing list